@@ -770,12 +770,12 @@ def play_sheet(notes, tempos, tom=-12):
     print('PageUp = Advance')
     print('PageDown = Rewind\n')
 
-    last_note = len(notes)
+    last_note = len(notes) - 1
     id_note = -1
     current_ms = 0
 
     old_time = ''
-    while id_note < last_note-1:
+    while id_note < last_note:
         # Delete = Stop forever
         # pause = Resume/Pause
         id_note += 1
@@ -887,8 +887,17 @@ def play_sheet(notes, tempos, tom=-12):
                     directinput.keyUp(keys[notes[id_note] - 24])
 
     for fix_stop in keys:
-        if keyboard.is_pressed(fix_stop):
-            directinput.keyUp(fix_stop)
+        if '+' in fix_stop:
+            part1 = fix_stop[0:fix_stop.index('+') - 1]
+            part2 = fix_stop[fix_stop.index('+') + 2:]
+            if keyboard.is_pressed(part1):
+                directinput.keyUp(part1)
+            if keyboard.is_pressed(part2):
+                directinput.keyUp(part2)
+        else:
+            if keyboard.is_pressed(fix_stop):
+                directinput.keyUp(fix_stop)
+
     while True:
         set = 0
         if transpose < set:
